/**
 * A `connectedDomainSetupInfo` object holds information the connected domain's
 * external registrar and some DNS records. You can use this information to guide
 * the site owner through the domain's setup process.
 */
export interface ConnectedDomainSetupInfo extends ConnectedDomainSetupInfoDnsRecordsOneOf {
    /**
     * Information about domains connected using nameservers. Available only for
     * `{"connectionType": "NAMESERVERS"}`.
     */
    nameserverRecord?: NameserverRecord;
    /**
     * Information about domains connected by pointing.  Available only for
     * `{"connectionType": "POINTING"}`.
     * @readonly
     */
    pointingRecords?: PointingRecords;
    /**
     * Information about subdomains.  Available only for subdomains.
     * @readonly
     */
    subdomainRecords?: SubdomainRecords;
    /** ID of the connected domain. Identical to the domain name including TLD. */
    connectedDomainId?: string;
    /**
     * Information about the external domain registrar including current name
     * servers.
     */
    registrar?: Registrar;
}
/** @oneof */
export interface ConnectedDomainSetupInfoDnsRecordsOneOf {
    /**
     * Information about domains connected using nameservers. Available only for
     * `{"connectionType": "NAMESERVERS"}`.
     */
    nameserverRecord?: NameserverRecord;
    /**
     * Information about domains connected by pointing.  Available only for
     * `{"connectionType": "POINTING"}`.
     * @readonly
     */
    pointingRecords?: PointingRecords;
    /**
     * Information about subdomains.  Available only for subdomains.
     * @readonly
     */
    subdomainRecords?: SubdomainRecords;
}
export interface Registrar {
    /**
     * Name of the external domain registrar. For subdomains it's the registrar of the root domain.
     * @readonly
     */
    name?: string | null;
    /**
     * Values of the current name server records. In case you connect an external
     * domain using name servers, site owners must replace these current name servers
     * with the new name servers found in `connectedDomainSetupInfo.nameserverRecord.nsRecord.values`
     * during the initial domain setup.
     * The replacement can't be performed through Wix APIs, you must use the
     * infrastructure of the external domain registrar. Read more about
     * [connecting domains using nameservers](https://dev.wix.com/api/rest/account-level-apis/connected-domains/sample-flows#account-level-apis_connected-domains_sample-flows_connect-an-external-domain-using-nameservers).
     * @readonly
     */
    nameServers?: string[];
}
/** Information about domains connected by nameservers. */
export interface NameserverRecord {
    /**
     * Default [nameserver record](https://en.wikipedia.org/wiki/List_of_DNS_record_types#NS).
     * @readonly
     */
    nsRecord?: NsRecord;
}
export interface NsRecord {
    /** Domain host name. For example `domain.com` or `mail.domain.com`. Can be a subdomain. */
    hostName?: string;
    /** [Time to live](https://en.wikipedia.org/wiki/Time_to_live) in seconds. */
    ttl?: number;
    /** DNS record values. */
    values?: string[];
}
/** Information about domains connected by pointing. */
export interface PointingRecords {
    /**
     * [Address record](https://en.wikipedia.org/wiki/List_of_DNS_record_types#A).
     * @readonly
     */
    aRecord?: ARecord;
    /**
     * [Canonical Name record](https://en.wikipedia.org/wiki/CNAME_record).
     * @readonly
     */
    cnameRecord?: CnameRecord;
}
export interface ARecord {
    /** Domain host name. For example `domain.com` or `mail.domain.com`. Can be a subdomain. */
    hostName?: string;
    /** [Time to live](https://en.wikipedia.org/wiki/Time_to_live) in seconds. */
    ttl?: number;
    /** DNS record values. */
    values?: string[];
}
export interface CnameRecord {
    /** Domain host name. For example `domain.com` or `mail.domain.com`. Can be a subdomain. */
    hostName?: string;
    /** [Time to live](https://en.wikipedia.org/wiki/Time_to_live) in seconds. */
    ttl?: number;
    /** DNS record value. */
    value?: string;
}
/** Information about subdomains. */
export interface SubdomainRecords {
    /**
     * [Canonical Name records](https://en.wikipedia.org/wiki/CNAME_record).
     * @readonly
     */
    cnameRecords?: CnameRecord[];
}
export interface GetSetupInfoRequest {
    /** Domain name including TLD */
    domain?: string;
    /**
     * How the domain should be to connected the Wix site.
     *
     * + `"UNKNOWN_CONNECTION_TYPE"`: supported only for subdomain.
     * + `"POINTING"`: Get domain or subdomain setup by pointing
     * + `"NAMESERVERS"`: Get domain setup by nameservers
     * + `"HIDDEN"`: supported only for subdomain.
     */
    connectionType?: ConnectionType;
    /** Whether to return registrar information or not. Default is false. */
    includeRegistrar?: boolean;
}
export declare enum ConnectionType {
    /** Used by sub domain */
    UNKNOWN_CONNECTION_TYPE = "UNKNOWN_CONNECTION_TYPE",
    POINTING = "POINTING",
    NAMESERVERS = "NAMESERVERS",
    /**
     * internal used by photography company.
     * when a customer creates a photo album, each album has its sub domain and this sub domain
     * is not visible in my domains page.
     */
    HIDDEN = "HIDDEN"
}
export interface GetSetupInfoResponse {
    /** Retrieved setup information. */
    domainSetupInfo?: ConnectedDomainSetupInfo;
}
export interface PreCreateConnectedDomainRequest {
    /** Domain name including TLD */
    domain?: string;
}
export interface PreCreateConnectedDomainResponse {
}
export interface GetConnectedDomainSetupInfoRequest {
    /**
     * ID of the connected domain to retrieve setup information for.
     * Identical to the domain name including TLD.
     */
    connectedDomainId: string;
}
export interface GetConnectedDomainSetupInfoResponse {
    /** Retrieved setup information. */
    connectedDomainSetupInfo?: ConnectedDomainSetupInfo;
}
interface NsRecordNonNullableFields {
    hostName: string;
    ttl: number;
    values: string[];
}
interface NameserverRecordNonNullableFields {
    nsRecord?: NsRecordNonNullableFields;
}
interface ARecordNonNullableFields {
    hostName: string;
    ttl: number;
    values: string[];
}
interface CnameRecordNonNullableFields {
    hostName: string;
    ttl: number;
    value: string;
}
interface PointingRecordsNonNullableFields {
    aRecord?: ARecordNonNullableFields;
    cnameRecord?: CnameRecordNonNullableFields;
}
interface SubdomainRecordsNonNullableFields {
    cnameRecords: CnameRecordNonNullableFields[];
}
interface RegistrarNonNullableFields {
    nameServers: string[];
}
export interface ConnectedDomainSetupInfoNonNullableFields {
    nameserverRecord?: NameserverRecordNonNullableFields;
    pointingRecords?: PointingRecordsNonNullableFields;
    subdomainRecords?: SubdomainRecordsNonNullableFields;
    connectedDomainId: string;
    registrar?: RegistrarNonNullableFields;
}
export interface GetConnectedDomainSetupInfoResponseNonNullableFields {
    connectedDomainSetupInfo?: ConnectedDomainSetupInfoNonNullableFields;
}
/**
 * Retrieves information for the initial setup of a connected domain.
 *
 *
 * You must pass the relevant Wix account ID in the header of the call.
 *
 * > __Important:__ This call requires an account level API key and cannot be authenticated with the standard authorization header.
 * @param connectedDomainId - ID of the connected domain to retrieve setup information for.
 * Identical to the domain name including TLD.
 * @public
 * @requiredField connectedDomainId
 * @permissionId DOMAINS.READ_CONNECTED_DOMAINS
 * @returns Retrieved setup information.
 * @fqn com.wixpress.premium.domain.connected.ConnectedDomainSetupInfoService.GetConnectedDomainSetupInfo
 */
export declare function getConnectedDomainSetupInfo(connectedDomainId: string): Promise<ConnectedDomainSetupInfo & ConnectedDomainSetupInfoNonNullableFields>;
export {};
